@@ -1,4 +1,6 @@
 pub mod accounts_update_notifier;
 pub mod accountsdb_plugin_manager;
 pub mod accountsdb_plugin_service;
+pub mod slot_status_notifier;
 pub mod slot_status_observer;
+pub mod transaction_notifier;
